﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;

namespace XamDataChart
{
    public class MainWindowViewModel : INotifyPropertyChanged
    {
        #region INotifyPropertyChanged Implementation
        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion

        private ObservableCollection<ChartData> _data;
        public ObservableCollection<ChartData> Data
        {
            get { return _data; }
            set
            {
                if (_data != value)
                {
                    _data = value;
                    OnPropertyChanged("Data");
                }
            }
        }

        private string _series1Title;
        public string Series1Title
        {
            get { return _series1Title; }
            set
            {
                if (_series1Title != value)
                {
                    _series1Title = value;
                    OnPropertyChanged("Series1Title");
                }
            }
        }

        private string _series2Title;
        public string Series2Title
        {
            get { return _series2Title; }
            set
            {
                if (_series2Title != value)
                {
                    _series2Title = value;
                    OnPropertyChanged("Series2Title");
                }
            }
        }

        private string _series3Title;
        public string Series3Title
        {
            get { return _series3Title; }
            set
            {
                if (_series3Title != value)
                {
                    _series3Title = value;
                    OnPropertyChanged("Series3Title");
                }
            }
        }

        public MainWindowViewModel()
        {
            Data = ChartData.GenerateData(20);
            Series1Title = "Company One";
            Series2Title = "Company Two";
            Series3Title = "Company Three";
        }
    }

    public class ChartData
    {
        public DateTime Date { get; set; }
        public double Value1 { get; set; }
        public double Value2 { get; set; }
        public double Value3 { get; set; }
        public string Title { get; set; }

        public static ObservableCollection<ChartData> GenerateData(int count)
        {
            ObservableCollection<ChartData> data = new ObservableCollection<ChartData>();

            Random r = new Random();

            ChartData data0 = new ChartData
            {
                Date = DateTime.Now,
                Value1 = r.Next(20, 40),
                Value2 = 0.0,//r.Next(5, 420),
                Value3 = r.Next(10, 4000),
            };

            data.Add(data0);

            for (int i = 1; i < count; i++)
            {
                ChartData dat = new ChartData
                {
                    Date = DateTime.Now.AddDays(i),
                };

                if (r.NextDouble() > .5)
                {
                    dat.Value1 = data[i - 1].Value1 + r.NextDouble();
                    dat.Value2 = 0.0;// data[i - 1].Value2 + r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 + r.NextDouble();
                    dat.Title = "Title " + i;
                }
                else
                {
                    dat.Value1 = data[i - 1].Value1 - r.NextDouble();
                    dat.Value2 = 0.0;//data[i - 1].Value2 + i + r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 - r.NextDouble();
                    dat.Title = "Title " + i;
                }

                data.Add(dat);
            }

            return data;
        }
    }
}
